# Trick to suppress some check warnings
globalVariables(c("%>%", "identifier", "method", "variable", "value", "sd", 
  "SD", "N", "median", "M", "pct", "DV", "group", "term", "terms", ".", "n",
  "column"))